@@ -751,10 +751,10 @@ sub TableSpec_get_conf {
   
   # Special: map all column prop names into 'column_properties'
   $param = 'column_properties' if ($col_prop_names{$param});
-
+  
   my $value = $storage->{$param};
   
-  # FIXME FIXME FIXME
+  # --- FIXME FIXME FIXME
   # In the original design of the TableSpec_cnf internals, which
   # was too fancy for its own good, meta/type information was
   # transparently stored to be able to do things like remember
@@ -771,8 +771,9 @@ sub TableSpec_get_conf {
   # however! It is just temporary until those outside places
   # can be confirmed and eliminated, or a proper deprecation plan
   # can be made, should that even be needed...
+  
   if(wantarray && ref($value)) {
-    warn join("\n",'',
+    cluck join("\n",'',
       "  WARNING: calling TableSpec_get_conf() in LIST context",
       "  is deprecated, please update your code.",
       "   --> Auto-dereferencing param '$param' $value",'',
@@ -781,6 +782,11 @@ sub TableSpec_get_conf {
     return %$value if (ref($value) eq 'HASH');
   }
   
+  # When trying to get a param that does not exist, return an
+  # empty list if called in LIST context, otherwise undef
+  return wantarray ? () : undef unless (exists $storage->{$param});
+  # ---
+  
   return $value;
 }
 
@@ -962,7 +968,7 @@ sub proxy_method_get_changed {
 	
 	@changed = @new_changed;
 	
-	my $col_props = { $self->TableSpec_get_conf('columns') };
+	my $col_props = $self->TableSpec_get_conf('columns');
 	
 	my %diff = map {
 		$_ => { 
